@@ -1,10 +1,8 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Author: Albert King
-date: 2020/3/3 20:46
-contact: jindaxiang@163.com
-desc: Just for test file
+Date: 2021/12/9 17:20
+Desc: Just for test file
 """
 import akshare as ak
 
@@ -19,5 +17,5 @@ def test_demo():
     assert cost_living_df.shape[0] != 0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     test_demo()
